@@ -3,7 +3,8 @@ import requests
 from django.db.models import get_model
 
 from .errors import EasyRecException
-
+import logging
+logger = logging.getLogger(__name__)
 
 Product = get_model('catalogue', 'Product')
 
@@ -323,7 +324,8 @@ class EasyRec(object):
         except:
             return ['ITEM',]
         try:
-            return response['itemTypes']['itemType']
+            self._item_types = response['itemTypes']['itemType']
+            return self._item_types
         except KeyError:
             return ['ITEM',]
 
@@ -352,12 +354,18 @@ class EasyRec(object):
             'GET': self._requests.get,
             'POST': self._requests.post
         }.get(method, self._requests.get)
+        logger.debug("%s: %s %s" % (method, url, params))
         response = func(url, params=params)
+        logger.debug("%s: %s" % (
+            response.status_code,
+            response.text
+        ))
         response.raise_for_status()
         content = response.json()
         self.check_response_for_errors(content)
         return content
 
+
     def _recommendations_to_products(self, recommendations):
         upcs = []
         recommendeditems = recommendations.get('recommendeditems')
